==> esp32c3-0.2.0.crate: esp32c3-0.2.0/src/ds/query_key_wrong.rs <==
#[doc = "Register `QUERY_KEY_WRONG` reader"]
pub struct R(crate::R<QUERY_KEY_WRONG_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<QUERY_KEY_WRONG_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<QUERY_KEY_WRONG_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<QUERY_KEY_WRONG_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `QUERY_KEY_WRONG` reader - digital signature key wrong counter"]
pub struct QUERY_KEY_WRONG_R(crate::FieldReader<u8, u8>);
impl QUERY_KEY_WRONG_R {
    pub(crate) fn new(bits: u8) -> Self {
        QUERY_KEY_WRONG_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for QUERY_KEY_WRONG_R {
    type Target = crate::FieldReader<u8, u8>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:3 - digital signature key wrong counter"]
    #[inline(always)]
    pub fn query_key_wrong(&self) -> QUERY_KEY_WRONG_R {
        QUERY_KEY_WRONG_R::new((self.bits & 0x0f) as u8)
    }
}
#[doc = "DS query key-wrong counter register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [query_key_wrong](index.html) module"]
pub struct QUERY_KEY_WRONG_SPEC;
impl crate::RegisterSpec for QUERY_KEY_WRONG_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [query_key_wrong::R](R) reader structure"]
impl crate::Readable for QUERY_KEY_WRONG_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets QUERY_KEY_WRONG to value 0"]
impl crate::Resettable for QUERY_KEY_WRONG_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp32c3-0.4.0.crate: esp32c3-0.4.0/src/ds/query_key_wrong.rs <==
#[doc = "Register `QUERY_KEY_WRONG` reader"]
pub struct R(crate::R<QUERY_KEY_WRONG_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<QUERY_KEY_WRONG_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<QUERY_KEY_WRONG_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<QUERY_KEY_WRONG_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `QUERY_KEY_WRONG` reader - digital signature key wrong counter"]
pub struct QUERY_KEY_WRONG_R(crate::FieldReader<u8, u8>);
impl QUERY_KEY_WRONG_R {
    #[inline(always)]
    pub(crate) fn new(bits: u8) -> Self {
        QUERY_KEY_WRONG_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for QUERY_KEY_WRONG_R {
    type Target = crate::FieldReader<u8, u8>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:3 - digital signature key wrong counter"]
    #[inline(always)]
    pub fn query_key_wrong(&self) -> QUERY_KEY_WRONG_R {
        QUERY_KEY_WRONG_R::new((self.bits & 0x0f) as u8)
    }
}
#[doc = "DS query key-wrong counter register\n\nThis register you can [`read`]
(crate::generic::Reg::read). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [query_key_wrong]
(index.html) module"]
pub struct QUERY_KEY_WRONG_SPEC;
impl crate::RegisterSpec for QUERY_KEY_WRONG_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [query_key_wrong::R]
(R) reader structure"]
impl crate::Readable for QUERY_KEY_WRONG_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets QUERY_KEY_WRONG to value 0"]
impl crate::Resettable for QUERY_KEY_WRONG_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
